@@ -28,8 +28,11 @@ class JobBase(abc.ABC):
         should not be re-used
     :param bool hidden: Whether to hide the job's output in the UI
     :param bool autostart: Whether this job is started automatically
-    :param condition: Callable that gets no arguments and returns whether this
-        job is enabled or disabled
+    :param precondition: Callable that gets no arguments and returns whether
+        this job is enabled or disabled
+    :param prejobs: Sequence of :attr:`prerequisite jobs <prejobs>`
+    :param presignals: Mapping of :class:`jobs <JobBase>` to sequence of signals
+        (see :meth:`presignal`)
     :param callbacks: Mapping of :attr:`signal` names to callable or sequence of
         callables to :meth:`~.signal.Signal.register` for that signal
 
@@ -100,20 +103,20 @@ class JobBase(abc.ABC):
         return self._autostart
 
     @property
-    def condition(self):
+    def precondition(self):
         """
         Callable that gets no arguments and returns whether this job should
         be :meth:`started <start>`
 
         See also :attr:`is_enabled`.
         """
-        return self._condition
+        return self._precondition
 
-    @condition.setter
-    def condition(self, function):
+    @precondition.setter
+    def precondition(self, function):
         if not callable(function):
             raise TypeError(f'Not callable: {function!r}')
-        self._condition = function
+        self._precondition = function
 
     @property
     def prejobs(self):
@@ -131,24 +134,64 @@ class JobBase(abc.ABC):
     def prejobs(self, prejobs):
         self._prejobs = tuple(prejobs)
 
+    def presignal(self, job, signal):
+        """
+        Do not :attr:`enable <is_enabled>` this job until `job` :attr:`emits
+        <signal>` `signal`
+
+        When `job` emits `signal`, this job is enabled internally (so it can be
+        :meth:`started <start>`) and the `refresh_job_list` :attr:`signal` is
+        emitted.
+
+        The payload of `signal` is discarded. Register another callback for
+        `signal` if it is needed.
+
+        See also :attr:`is_enabled`.
+        """
+        # Indicate we are waiting for signal
+        self.presignals[job][signal] = False
+
+        def presignal_handler(*args, **kwargs):
+            self.presignals[job][signal] = True
+            # If all presignals were emitted from the expected `job`, we tell
+            # the TUI to check if the we are now ready to get started.
+            if all(self.presignals[job].values()):
+                self.signal.emit('refresh_job_list')
+
+        job.signal.register(signal, presignal_handler)
+
+    @cached_property
+    def presignals(self):
+        return collections.defaultdict(lambda: {})
+
     @property
     def is_enabled(self):
         """
         Whether this job is allowed to :meth:`start`
 
-        A job is enabled if :attr:`autostart` is `True`, :attr:`condition`
-        returns `True`, and all :attr:`prejobs` are either finished or disabled.
+        A job is enabled if :attr:`precondition` returns `True`, all
+        :attr:`prejobs` are either finished or disabled and all
+        :func:`presignal`\\ s have been emitted.
 
-        This property must be checked by the UI every time any job finishes. If
-        it is `True`, this job must be :meth:`started <start>` and displayed
+        This property must be checked by the UI every time any job finishes and
+        when the `refresh_job_list` :attr:`signal` is emitted. If this property
+        is `True`, this job must be :meth:`started <start>` and displayed
         (unless it is :attr:`hidden`).
         """
         return (
+            # Prejobs
             all(
                 (prejob.is_finished or not prejob.is_enabled)
                 for prejob in self.prejobs
             )
-            and self.condition()
+            # Presignals
+            and all(
+                was_emitted
+                for job_, presignals in self.presignals.items()
+                for signal_, was_emitted in presignals.items()
+            )
+            # Precondition
+            and self.precondition()
         )
 
     @property
@@ -190,18 +233,25 @@ class JobBase(abc.ABC):
         ``error``
             Emitted when :meth:`error` is called. Registered callbacks get the
             value passed to :meth:`error` as a positional argument.
+
+        ``refresh_job_list``
+            Emitted when the UI should to refresh the job list. The UI usually
+            only does this when a job finishes. This signal allows a job to
+            force the refresh immediately. Registered callbacks get no
+            arguments.
         """
         return self._signal
 
     def __init__(self, *, home_directory=None, cache_directory=None,
                  ignore_cache=False, hidden=False, autostart=True,
-                 condition=None, prejobs=(), callbacks={}, **kwargs):
+                 precondition=None, prejobs=(), presignals={}, callbacks={},
+                 **kwargs):
         self._home_directory = home_directory if home_directory else ''
         self._cache_directory = cache_directory if cache_directory else constants.DEFAULT_CACHE_DIRECTORY
         self._ignore_cache = bool(ignore_cache)
         self._hidden = bool(hidden)
         self._autostart = bool(autostart)
-        self.condition = condition if condition is not None else (lambda: True)
+        self.precondition = precondition if precondition is not None else (lambda: True)
         self._is_started = False
         self._is_executed = False
         self._exception = None
@@ -213,7 +263,15 @@ class JobBase(abc.ABC):
         self._finished_event = asyncio.Event()
         self.prejobs = prejobs
 
-        self._signal = utils.signal.Signal('output', 'info', 'warning', 'error', 'executed', 'finished')
+        self._signal = utils.signal.Signal(
+            'output',
+            'info',
+            'warning',
+            'error',
+            'executed',
+            'finished',
+            'refresh_job_list',
+        )
         self._signal.register('output', lambda output: self._output.append(str(output)))
         self._signal.register('warning', lambda warning: self._warnings.append(warning))
         self._signal.register('error', lambda error: self._errors.append(error))
@@ -231,6 +289,11 @@ class JobBase(abc.ABC):
                 for cb in callback:
                     self._signal.register(signal_name, cb)
 
+        # Register required signals from other jobs
+        for job, signals in presignals.items():
+            for signal in signals:
+                self.presignal(job, signal)
+
     def initialize(self):
         """
         Called by :meth:`__init__` with additional keyword arguments
@@ -265,9 +328,15 @@ class JobBase(abc.ABC):
             # the error from the failed job.
             _log.debug('%s: Not executing already finished job', self.name)
         elif not self.is_enabled:
-            # Job is waiting for another job (see `prejobs` property) or for a
-            # condition (see `condition` property)
+            # Job is waiting for prejob, presignal, precondition, etc
             _log.debug('%s: Not executing disabled job', self.name)
+            # _log.debug(
+            #     '%s: Not executing disabled job: prejobs=%s, presignals=%s, precondition=%s',
+            #     self.name,
+            #     [f'{prejob.name}:' + 'finished' if prejob.is_finished else 'running' for prejob in self.prejobs],
+            #     self._presignals,
+            #     self.precondition(),
+            # )
         else:
             if self._is_started:
                 raise RuntimeError('start() was already called')
@@ -291,7 +360,7 @@ class JobBase(abc.ABC):
 
     @property
     def is_started(self):
-        """Whether :meth:`start` was called"""
+        """Whether :meth:`start` was called while this job :attr:`is_enabled`"""
         return self._is_started
 
     async def wait(self):
