@@ -414,6 +414,10 @@ class TextFieldJob(JobBase):
             which will be called when the job is :meth:`executed
             <upsies.jobs.base.JobBase.execute>`. The return value is used as the
             initial text.
+
+            .. warning:: If this is a :class:`callable` of any kind, all
+                         exceptions are raised fatally. All expected exceptions
+                         should be handled in the (asynchronous) function.
         :param autofinish: Automatically :meth:`finish` after `text` is set
             successfully
         :param validator: Callable that gets text before job is finished. If
