@@ -6,7 +6,7 @@ import os
 import queue
 
 from .. import errors
-from ..utils import LazyModule, daemon, fs, image, timestamp, video
+from ..utils import LazyModule, daemon, fs, image, timestamp, torrent, video
 from . import JobBase
 
 import logging  # isort:skip
@@ -33,27 +33,34 @@ class ScreenshotsJob(JobBase):
     label = 'Screenshots'
     cache_id = None
 
-    def initialize(self, *, content_path, timestamps=(), count=0, from_all_videos=False):
+    def initialize(self, *, content_path, exclude_files=(), timestamps=(), count=0, from_all_videos=False):
         """
         Set internal state
 
-        :param str content_path: Path to file or directory
+        :param str content_path: Path to file or directory or sequence of paths
+        :param exclude_files: Sequence of glob patterns (:class:`str`) and
+            :class:`re.Pattern` objects (return value from :func:`re.compile`)
+            that are matched against the relative path within the generated
+            torrent
+
+            Glob patterns are matched case-insensitively.
+
+            .. note:: Non-video files and stuff like `Sample.mkv` are always
+                      excluded by :func:`.video.filter_main_videos`.
         :param timestamps: Screenshot positions in the video
         :type timestamps: sequence of "[[H+:]M+:]S+" strings or seconds
         :param count: How many screenshots to make
-
         :param bool from_all_videos: Whether to take `count` screenshots from
-            each video file beneath `content_path` or only from the first video
+            each video file or only from the first video
 
             See :func:`.video.find_videos` for more information.
 
-            If `content_path` is not a directory, enabling this has no effect.
-
         If `timestamps` and `count` are not given, screenshot positions are
         picked at even intervals. If `count` is larger than the number of
         `timestamps`, more timestamps are added.
         """
         self._content_path = content_path
+        self._exclude_files = exclude_files
         self._screenshots_created = 0
         self._screenshots_total = -1
         self._timestamps = timestamps
@@ -73,6 +80,7 @@ class ScreenshotsJob(JobBase):
             target=_screenshots_process,
             kwargs={
                 'content_path': self._content_path,
+                'exclude_files': self._exclude_files,
                 'timestamps': self._timestamps,
                 'count': self._count,
                 'from_all_videos': self._from_all_videos,
@@ -129,6 +137,102 @@ class ScreenshotsJob(JobBase):
             else:
                 return 1
 
+    @property
+    def content_path(self):
+        """
+        Path or sequence of file paths
+
+        If this is set to a single path, appropriate files are picked by
+        :func:`~.video.find_videos`.
+
+        If this is set to a sequence of file paths, non-video files and uncommon
+        playback durations are excluded. (See
+        :func:`~.video.filter_main_videos`.)
+
+        See also :attr:`from_all_videos`.
+
+        Setting this property when this job :attr:`~.JobBase.is_started` raises
+        :class:`RuntimeError`.
+        """
+        return self._content_path
+
+    @content_path.setter
+    def content_path(self, content_path):
+        if self.is_started:
+            raise RuntimeError('Cannot set content_path after job has been started')
+        else:
+            self._content_path = content_path
+
+    @property
+    def exclude_files(self):
+        """
+        Sequence of glob and :class:`regex <re.Pattern>` patterns to exclude
+
+        See :meth:`initialize` for more information.
+
+        Setting this property when this job :attr:`~.JobBase.is_started` raises
+        :class:`RuntimeError`.
+        """
+        return self._exclude_files
+
+    @exclude_files.setter
+    def exclude_files(self, exclude_files):
+        if self.is_started:
+            raise RuntimeError('Cannot set exclude_files after job has been started')
+        else:
+            self._exclude_files = exclude_files
+
+    @property
+    def from_all_videos(self):
+        """
+        Whether to make screenshots from all video files or only the first
+
+        Setting this property when this job :attr:`~.JobBase.is_started` raises
+        :class:`RuntimeError`.
+        """
+        return self._from_all_videos
+
+    @from_all_videos.setter
+    def from_all_videos(self, from_all_videos):
+        if self.is_started:
+            raise RuntimeError('Cannot set from_all_videos after job has been started')
+        else:
+            self._from_all_videos = from_all_videos
+
+    @property
+    def count(self):
+        """
+        How many screenshots to make per video file
+
+        Setting this property when this job :attr:`~.JobBase.is_started` raises
+        :class:`RuntimeError`.
+        """
+        return self._count
+
+    @count.setter
+    def count(self, count):
+        if self.is_started:
+            raise RuntimeError('Cannot set count after job has been started')
+        else:
+            self._count = count
+
+    @property
+    def timestamps(self):
+        """
+        Specific list of timestamps to make
+
+        Setting this property when this job :attr:`~.JobBase.is_started` raises
+        :class:`RuntimeError`.
+        """
+        return self._timestamps
+
+    @timestamps.setter
+    def timestamps(self, timestamps):
+        if self.is_started:
+            raise RuntimeError('Cannot set timestamps after job has been started')
+        else:
+            self._timestamps = timestamps
+
     @property
     def screenshots_total(self):
         """
@@ -147,39 +251,52 @@ class ScreenshotsJob(JobBase):
 
 
 def _screenshots_process(output_queue, input_queue,
-                         *, content_path, timestamps, count, from_all_videos,
+                         *, content_path, exclude_files, timestamps, count, from_all_videos,
                          output_dir, overwrite):
-    # Find appropriate video file(s) if `content_path` is a directory
+    video_files = list(_get_video_files(
+        output_queue,
+        content_path=content_path,
+        exclude_files=exclude_files,
+    ))
+    if not video_files:
+        output_queue.put((daemon.MsgType.error, 'No videos found'))
+        return
+
+    if not from_all_videos:
+        # Only create screenshots from first video
+        del video_files[1:]
+
+    timestamps_map = _map_timestamps(
+        video_files=video_files,
+        timestamps=timestamps,
+        count=count,
+    )
+
+    # Herald how many screenshots we are going to make
+    screenshots_total = sum((len(ts) for ts in timestamps_map.values()))
+    output_queue.put((daemon.MsgType.info, {'screenshots_total': screenshots_total}))
+
     try:
-        video_files = video.find_videos(content_path)
+        _screenshot_video_files(
+            output_queue, input_queue,
+            timestamps_map=timestamps_map,
+            output_dir=output_dir,
+            overwrite=overwrite,
+        )
+    except SystemExit:
+        # _maybe_terminate signals termination by raising SystemExit. This
+        # shouldn't cause any issues as long as we actually exit here.
+        pass
+
+
+def _get_video_files(output_queue, *, content_path, exclude_files):
+    # Make list of appropriate video file(s) from `content_path`
+    try:
+        filtered_files = torrent.filter_files(content_path, exclude=exclude_files)
+        return video.filter_main_videos(tuple(filtered_files))
     except errors.ContentError as e:
         output_queue.put((daemon.MsgType.error, str(e)))
-    else:
-        if not from_all_videos:
-            # Only create screenshots from first video
-            del video_files[1:]
-
-        timestamps_map = _map_timestamps(
-            video_files=video_files,
-            timestamps=timestamps,
-            count=count,
-        )
-
-        # Herald how many screenshots we are going to make
-        screenshots_total = sum((len(ts) for ts in timestamps_map.values()))
-        output_queue.put((daemon.MsgType.info, {'screenshots_total': screenshots_total}))
-
-        try:
-            _screenshot_video_files(
-                output_queue, input_queue,
-                timestamps_map=timestamps_map,
-                output_dir=output_dir,
-                overwrite=overwrite,
-            )
-        except SystemExit:
-            # _maybe_terminate signals termination by raising SystemExit. This
-            # shouldn't cause any issues as long as we actually exit here.
-            pass
+        return []
 
 
 def _screenshot_video_files(output_queue, input_queue, *, timestamps_map, output_dir, overwrite):
