@@ -2,12 +2,11 @@
 Create torrent file
 """
 
-import fnmatch
 import os
 import queue
 
 from .. import errors
-from ..utils import daemon, fs, is_regex_pattern, torrent
+from ..utils import daemon, fs, torrent
 from . import base
 
 import logging  # isort:skip
@@ -33,6 +32,11 @@ class CreateTorrentJob(base.JobBase):
             :func:`~.utils.torrent.create`) as a positional argument. (See also
             :func:`.fs.format_file_tree`.)
 
+        ``file_list``
+            Emitted when torrent creation begins. Registered callbacks get a
+            :class:`list` of paths to existing files that are in the torrent as
+            a positional argument.
+
         ``progress_update``
             Emitted at roughly equal intervals to provide information about the
             torrent creation progress. Registered callbacks get a
@@ -54,11 +58,14 @@ class CreateTorrentJob(base.JobBase):
         :param reuse_torrent_path: Path to existing torrent file to reuse piece
             hashes from (see :func:`~.utils.torrent.create`)
         :param exclude_files: Sequence of glob patterns (:class:`str`) and
-            :class:`re.Pattern` objects that are matched against the relative
-            path within the generated torrent
+            :class:`re.Pattern` objects (return value from :func:`re.compile`)
+            that are matched against the relative path within the generated
+            torrent
 
-            .. note:: This sequence is added to the ``exclude`` list in
-               :class:`~.base.TrackerConfigBase`.
+            Glob patterns are matched case-insensitively.
+
+            .. note:: This sequence is combined with
+                      :attr:`.TrackerBase.options`\\ ``["exclude"]``.
         """
         self._tracker = tracker
         self._content_path = content_path
@@ -69,13 +76,11 @@ class CreateTorrentJob(base.JobBase):
         )
 
         self._exclude_files = list(self._tracker.options['exclude'])
-        for pattern in exclude_files:
-            if not is_regex_pattern(pattern):
-                pattern = fnmatch.translate(str(pattern))
-            self._exclude_files.append(pattern)
+        self._exclude_files.extend(exclude_files)
 
         self.signal.add('announce_url')
         self.signal.add('file_tree')
+        self.signal.add('file_list')
         self.signal.add('progress_update')
         self._torrent_process = None
         self._activity = ''
@@ -134,7 +139,7 @@ class CreateTorrentJob(base.JobBase):
                 'source': self._tracker.options['source'],
                 'exclude': self._exclude_files,
             },
-            init_callback=self._handle_file_tree,
+            init_callback=self._handle_files,
             info_callback=self._handle_info_update,
             error_callback=self._handle_error,
             result_callback=self._handle_torrent_created,
@@ -157,8 +162,9 @@ class CreateTorrentJob(base.JobBase):
         if self._activity == 'searching' and self._torrent_process:
             self._torrent_process.send(daemon.MsgType.terminate, torrent.SKIP_SEARCHING)
 
-    def _handle_file_tree(self, file_tree):
-        self.signal.emit('file_tree', file_tree)
+    def _handle_files(self, files):
+        self.signal.emit('file_tree', files.tree)
+        self.signal.emit('file_list', files.list)
 
     def _handle_info_update(self, info):
         if isinstance(info, torrent.CreateTorrentProgress):
@@ -201,12 +207,12 @@ def _torrent_process(output_queue, input_queue, *args, **kwargs):
         except queue.Empty:
             return (None, None)
 
-    def init_callback(file_tree):
+    def init_callback(files):
         typ, msg = read_input_queue()
         if typ == daemon.MsgType.terminate:
             return 'cancel'
         else:
-            output_queue.put((daemon.MsgType.init, file_tree))
+            output_queue.put((daemon.MsgType.init, files))
 
     def progress_callback(progress):
         typ, msg = read_input_queue()
