@@ -43,11 +43,22 @@ class BhdTrackerJobs(TrackerJobsBase):
         user, e.g. with a CLI argument
         """
         if self.options.get('only_description', False):
-            # Only activate description_job and its dependencies
-            return (self.description_job, self.screenshots_job, self.upload_screenshots_job)
+            return self.get_job_and_dependencies(
+                self.description_job,
+                # `screenshots_job` is needed by `upload_screenshots_job`, but
+                # `upload_screenshots_job` is a `QueueJobBase`, which doesn't
+                # know anything about the job it gets input from and therefore
+                # can't tells us that it needs `screenshots_job`.
+                self.screenshots_job,
+            )
         elif self.options.get('only_title', False):
-            # Only activate release_name_job and its dependencies
-            return (self.release_name_job, self.imdb_job)
+            return self.get_job_and_dependencies(
+                self.release_name_job,
+                # `release_name_job` doesn't depend on `imdb_job` (or any other
+                # webdb), but we want the correct name, year, etc in the release
+                # name.
+                self.imdb_job,
+            )
         else:
             # Activate all jobs in jobs_before/after_upload
             return ()
@@ -57,7 +68,7 @@ class BhdTrackerJobs(TrackerJobsBase):
         return jobs.dialog.ChoiceJob(
             name=self.get_job_name('category'),
             label='Category',
-            condition=self.make_job_condition('category_job'),
+            precondition=self.make_precondition('category_job'),
             prejobs=(
                 self.release_name_job,
             ),
@@ -87,7 +98,7 @@ class BhdTrackerJobs(TrackerJobsBase):
         return jobs.dialog.ChoiceJob(
             name=self.get_job_name('type'),
             label='Type',
-            condition=self.make_job_condition('type_job'),
+            precondition=self.make_precondition('type_job'),
             prejobs=(
                 self.release_name_job,
             ),
@@ -146,7 +157,7 @@ class BhdTrackerJobs(TrackerJobsBase):
         return jobs.dialog.ChoiceJob(
             name=self.get_job_name('source'),
             label='Source',
-            condition=self.make_job_condition('source_job'),
+            precondition=self.make_precondition('source_job'),
             prejobs=(
                 self.release_name_job,
             ),
@@ -182,7 +193,10 @@ class BhdTrackerJobs(TrackerJobsBase):
         return jobs.dialog.TextFieldJob(
             name=self.get_job_name('description'),
             label='Description',
-            condition=self.make_job_condition('description_job'),
+            precondition=self.make_precondition('description_job'),
+            prejobs=(
+                self.upload_screenshots_job,
+            ),
             text=self.generate_description,
             autofinish=True,
             read_only=True,
@@ -194,8 +208,7 @@ class BhdTrackerJobs(TrackerJobsBase):
     }
 
     async def generate_description(self):
-        # Wait until all screenshots are uploaded
-        await self.upload_screenshots_job.wait()
+        assert self.upload_screenshots_job.is_finished
 
         rows = []
         screenshot_groups = as_groups(
@@ -227,7 +240,11 @@ class BhdTrackerJobs(TrackerJobsBase):
         return jobs.dialog.TextFieldJob(
             name=self.get_job_name('tags'),
             label='Tags',
-            condition=self.make_job_condition('tags_job'),
+            precondition=self.make_precondition('tags_job'),
+            prejobs=(
+                self.release_name_job,
+                self.scene_check_job,
+            ),
             text=self.generate_tags,
             autofinish=True,
             read_only=True,
@@ -235,8 +252,8 @@ class BhdTrackerJobs(TrackerJobsBase):
         )
 
     async def generate_tags(self):
-        await self.release_name_job.wait()
-        await self.scene_check_job.wait()
+        assert self.release_name_job.is_finished
+        assert self.scene_check_job.is_finished
 
         # Any additional tags separated by comma(s). (Commentary, 2in1, Hybrid,
         # OpenMatte, 2D3D, WEBRip, WEBDL, 3D, 4kRemaster, DualAudio, EnglishDub,
