@@ -5,9 +5,8 @@ Dummy tracker for testing and debugging
 import asyncio
 import os
 
-from .. import errors, jobs
+from .. import errors, jobs, utils
 from ..utils import cached_property
-from ..utils.types import ReleaseType
 from . import base
 
 import logging  # isort:skip
@@ -19,7 +18,7 @@ class DummyTrackerConfig(base.TrackerConfigBase):
         'base_url'   : 'http://localhost',
         'username'   : '',
         'password'   : '',
-        'exclude'    : [],
+        'exclude'    : (),
         'source'     : 'DMY',
         'image_host' : 'dummy',
     }
@@ -77,10 +76,10 @@ class DummyTrackerJobs(base.TrackerJobsBase):
             return jobs.dialog.ChoiceJob(
                 name=self.get_job_name('category'),
                 label='Category',
-                condition=self.make_job_condition('category_job'),
+                precondition=self.make_precondition('category_job'),
                 choices=(
                     (str(typ).capitalize(), typ)
-                    for typ in ReleaseType if typ
+                    for typ in utils.types.ReleaseType if typ
                 ),
                 autodetected=self.release_name.type,
                 **self.common_job_args(),
