@@ -37,17 +37,16 @@ class MtvTrackerJobs(TrackerJobsBase):
     @property
     def isolated_jobs(self):
         if self.options.get('only_description', False):
-            return (
-                self.mediainfo_job,
-                self.screenshots_job,
-                self.upload_screenshots_job,
+            return self.get_job_and_dependencies(
                 self.description_job,
+                # `screenshots_job` is needed by `upload_screenshots_job`, but
+                # `upload_screenshots_job` is a `QueueJobBase`, which doesn't
+                # know anything about the job it gets input from and therefore
+                # can't tells us that it needs `screenshots_job`.
+                self.screenshots_job,
             )
         elif self.options.get('only_title', False):
-            return (
-                self.category_job,
-                self.imdb_job,
-                self.scene_check_job,
+            return self.get_job_and_dependencies(
                 self.title_job,
             )
         else:
@@ -59,7 +58,7 @@ class MtvTrackerJobs(TrackerJobsBase):
         return jobs.dialog.ChoiceJob(
             name=self.get_job_name('category'),
             label='Category',
-            condition=self.make_job_condition('category_job'),
+            precondition=self.make_precondition('category_job'),
             autodetect=self.autodetect_category,
             choices=[
                 (c['label'], c['value'])
@@ -136,9 +135,13 @@ class MtvTrackerJobs(TrackerJobsBase):
         return jobs.dialog.TextFieldJob(
             name=self.get_job_name('title'),
             label='Title',
-            prejobs=(self.category_job, self.scene_check_job, self.imdb_job),
+            prejobs=(
+                self.category_job,
+                self.scene_check_job,
+                self.imdb_job,
+            ),
             text=self.generate_title,
-            condition=self.make_job_condition('title_job'),
+            precondition=self.make_precondition('title_job'),
             **self.common_job_args(),
         )
 
@@ -163,9 +166,12 @@ class MtvTrackerJobs(TrackerJobsBase):
         return jobs.dialog.TextFieldJob(
             name=self.get_job_name('description'),
             label='Description',
-            prejobs=(self.mediainfo_job, self.upload_screenshots_job),
+            prejobs=(
+                self.mediainfo_job,
+                self.upload_screenshots_job,
+            ),
             text=self.generate_description,
-            condition=self.make_job_condition('description_job'),
+            precondition=self.make_precondition('description_job'),
             autofinish=True,
             read_only=True,
             hidden=True,
