@@ -25,6 +25,9 @@ class PtpTracker(TrackerBase):
     TrackerConfig = PtpTrackerConfig
     TrackerJobs = PtpTrackerJobs
 
+    def __init__(self, *args, **kwargs):
+        raise RuntimeError('PTP support is not done yet.')
+
     @property
     def _base_url(self):
         return self.options['base_url']
@@ -224,31 +227,43 @@ class PtpTracker(TrackerBase):
         """
         Convert IMDb ID to PTP group ID
 
+        Any :class:`~.RequestError` is caught and passed to
+        :meth:`.TrackerBase.error`.
+
         :return: PTP group ID or `None` if PTP doesn't have a group for
             `imdb_id`
         """
         _log.debug('%s: Fetching PTP group ID', imdb_id)
-        await self.login()
-        response = await self._request(
-            method='GET',
-            url=self._torrents_url,
-            params={
-                'imdb': self.normalize_imdb_id(imdb_id),
-                'json': '1',
-            },
-            cache=True,
-        )
-        match = re.search(r'id=(\d+)', response.headers.get('location', ''))
-        if match:
-            _log.debug('%s: PTP group ID: %s', imdb_id, match.group(1))
-            return match.group(1)
+        try:
+            await self.login()
+            response = await self._request(
+                method='GET',
+                url=self._torrents_url,
+                params={
+                    'imdb': self.normalize_imdb_id(imdb_id),
+                    'json': '1',
+                },
+                cache=True,
+            )
+
+        except errors.RequestError as e:
+            self.error(e)
+
         else:
-            _log.debug('%s: No PTP group ID', imdb_id)
+            match = re.search(r'id=(\d+)', response.headers.get('location', ''))
+            if match:
+                _log.debug('%s: PTP group ID: %s', imdb_id, match.group(1))
+                return match.group(1)
+            else:
+                _log.debug('%s: No PTP group ID', imdb_id)
 
     async def get_ptp_metadata(self, imdb_id, key=None):
         """
         Get metadata from PTP website
 
+        Any :class:`~.RequestError` is caught and passed to
+        :meth:`.TrackerBase.error`.
+
         :param imdb_id: IMDb ID (e.g. ``tt123456``)
         """
         if key:
@@ -257,22 +272,29 @@ class PtpTracker(TrackerBase):
             _log.debug('%s: Fetching metadata from PTP', imdb_id, key)
 
         assert imdb_id, imdb_id
-        await self.login()
-        response = await self._request(
-            method='GET',
-            url=self._ajax_url,
-            params={
-                'action': 'torrent_info',
-                'imdb': self.normalize_imdb_id(imdb_id),
-                'fast': '1',
-            },
-            cache=True,
-        )
-        results = response.json()
-        assert len(results) == 1
-        if key is None:
-            _log.debug('%s: PTP metadata: %s', imdb_id, results[0])
-            return results[0]
+
+        try:
+            await self.login()
+            response = await self._request(
+                method='GET',
+                url=self._ajax_url,
+                params={
+                    'action': 'torrent_info',
+                    'imdb': self.normalize_imdb_id(imdb_id),
+                    'fast': '1',
+                },
+                cache=True,
+            )
+            results = response.json()
+
+        except errors.RequestError as e:
+            self.error(e)
+
         else:
-            _log.debug('%s: PTP %s: %s', imdb_id, key, results[0][key])
-            return results[0][key]
+            assert len(results) == 1
+            if key is None:
+                _log.debug('%s: PTP metadata: %s', imdb_id, results[0])
+                return results[0]
+            else:
+                _log.debug('%s: PTP %s: %s', imdb_id, key, results[0][key])
+                return results[0][key]
