@@ -335,7 +335,8 @@ class CommandBase(abc.ABC):
         """
         Sequence of :class:`~.jobs.base.JobBase` objects
 
-        For convenience, the sequence may also contain `None` instead.
+        The returned sequence may also contain `None` for inactive jobs, which
+        will be ignored.
         """
 
     @property
