@@ -23,6 +23,10 @@ class mediainfo(CommandBase):
             'type': utils.argtypes.content,
             'help': 'Path to release content',
         },
+        ('--from-all-videos', '-a'): {
+            'action': 'store_true',
+            'help': 'Get mediainfo from each video file beneath CONTENT',
+        },
     }
 
     @utils.cached_property
@@ -33,5 +37,6 @@ class mediainfo(CommandBase):
                 cache_directory=self.cache_directory,
                 ignore_cache=self.args.ignore_cache,
                 content_path=self.args.CONTENT,
+                from_all_videos=self.args.from_all_videos,
             ),
         )
