@@ -55,7 +55,7 @@ class release_name(CommandBase):
         )
 
     def _update_release_name(self, imdb_id):
-        self.release_name_job.add_task(
+        self.release_name_job.attach_task(
             self.release_name_job.fetch_text(
                 coro=self.release_name.fetch_info(webdb=self.imdb, webdb_id=imdb_id),
                 nonfatal_exceptions=(
