@@ -16,6 +16,21 @@ class screenshots(CommandBase):
             'type': utils.argtypes.content,
             'help': 'Path to release content',
         },
+        ('--exclude-files', '--ef'): {
+            'nargs': '+',
+            'metavar': 'PATTERN',
+            'help': ('Glob pattern to exclude from CONTENT '
+                     '(matched case-insensitively against path relative to CONTENT)'),
+            'default': (),
+        },
+        ('--exclude-files-regex', '--efr'): {
+            'nargs': '+',
+            'metavar': 'PATTERN',
+            'help': ('Regular expression to exclude from CONTENT '
+                     '(matched case-sensitively against path relative to CONTENT)'),
+            'type': utils.argtypes.regex,
+            'default': (),
+        },
         ('--timestamps', '-t'): {
             'nargs': '+',
             'default': (),
@@ -52,6 +67,10 @@ class screenshots(CommandBase):
             cache_directory=self.cache_directory,
             ignore_cache=self.args.ignore_cache,
             content_path=self.args.CONTENT,
+            exclude_files=(
+                tuple(self.args.exclude_files)
+                + tuple(self.args.exclude_files_regex)
+            ),
             timestamps=self.args.timestamps,
             count=self.args.number,
             from_all_videos=self.args.from_all_videos,
