@@ -104,7 +104,7 @@ class set(CommandBase):
             return (self.fetch_ptpimg_apikey_job,)
         else:
             return (
-                jobs.config.SetJob(
+                jobs.set.SetJob(
                     config=self.config,
                     option=self.args.OPTION,
                     # VALUE is a list. The Config class should convert lists to
