@@ -2,6 +2,8 @@
 Commands related to torrent files
 """
 
+import os
+
 import aiobtclientapi
 
 from .... import constants, jobs, trackers, utils
@@ -83,7 +85,7 @@ class torrent_create(CommandBase):
                         'nargs': '+',
                         'metavar': 'PATTERN',
                         'help': ('Glob pattern to exclude from torrent '
-                                 '(matched case-sensitively against path in torrent)'),
+                                 '(matched case-insensitively against path in torrent)'),
                         'default': (),
                     },
                     ('--exclude-files-regex', '--efr'): {
@@ -150,7 +152,8 @@ class torrent_create(CommandBase):
                          **vars(self.args)},
             ),
             exclude_files=(
-                tuple(self.args.exclude_files)
+                tuple(self.config['trackers'][self.tracker_name]['exclude'])
+                + tuple(self.args.exclude_files)
                 + tuple(self.args.exclude_files_regex)
             ),
         )
@@ -170,7 +173,7 @@ class torrent_create(CommandBase):
                     username=config['username'],
                     password=config['password'],
                 ),
-                download_path=utils.fs.dirname(self.args.CONTENT),
+                download_path=utils.fs.dirname(os.path.abspath(self.args.CONTENT)),
                 check_after_add=config['check_after_add'],
             )
             # Pass CreateTorrentJob output to AddTorrentJob input.
