@@ -29,6 +29,10 @@ class SceneCheckJobWidget(JobWidgetBase):
         self._radiolist = widgets.RadioList()
         self._activity_indicator = widgets.ActivityIndicator(
             active=True,
+            format='\n'.join((
+                '{indicator} Checking for scene release',
+                'Press <Ctrl-s n> to mark this as a non-scene release.',
+            )),
             style='class:info',
             extend_width=True,
         )
@@ -36,6 +40,13 @@ class SceneCheckJobWidget(JobWidgetBase):
         self.job.signal.register('ask_release_name', self._ask_release_name)
         self.job.signal.register('ask_is_scene_release', self._ask_is_scene_release)
 
+        @self.keybindings_global.add(
+            'c-s', 'n',
+            filter=Condition(lambda: self._question.text == ''),
+        )
+        def _(event):
+            self.job.finalize(SceneCheckResult.false)
+
     def _ask_release_name(self, release_names):
         _log.debug('Asking for release name: %r', release_names)
 
