@@ -82,9 +82,9 @@ class WebDbSearchJobWidget(JobWidgetBase):
         else:
             # The same query was accepted twice without changing it.
             # Select focused search result.
-            selected = self._widgets['search_results'].focused_result
-            if selected is not None:
-                self.job.result_selected(selected)
+            focused = self._widgets['search_results'].focused_result
+            if focused is not None:
+                self.job.result_selected(focused)
             else:
                 self.job.result_selected(None)
         self.invalidate()
@@ -144,26 +144,28 @@ class WebDbSearchJobWidget(JobWidgetBase):
             widgets.vspacer,
         ]
 
-        @self.bind_key('down')
-        @self.bind_key('c-n')
-        @self.bind_key('tab')
+        @self.keybindings_local.add('down')
+        @self.keybindings_local.add('c-n')
+        @self.keybindings_local.add('tab')
         def _(event):
-            prev_result = self._widgets['search_results'].focused_result
+            prev_focused = self._widgets['search_results'].focused_result
             self._widgets['search_results'].focus_next()
-            if prev_result != self._widgets['search_results'].focused_result:
-                self.job.result_focused(self._widgets['search_results'].focused_result)
+            now_focused = self._widgets['search_results'].focused_result
+            if prev_focused != now_focused:
+                self.job.result_focused(now_focused)
 
-        @self.bind_key('up')
-        @self.bind_key('c-p')
-        @self.bind_key('s-tab')
+        @self.keybindings_local.add('up')
+        @self.keybindings_local.add('c-p')
+        @self.keybindings_local.add('s-tab')
         def _(event):
-            prev_result = self._widgets['search_results'].focused_result
-            self._widgets['search_results'].select_previous()
-            if prev_result != self._widgets['search_results'].focused_result:
-                self.job.result_focused(self._widgets['search_results'].focused_result)
+            prev_focused = self._widgets['search_results'].focused_result
+            self._widgets['search_results'].focus_previous()
+            now_focused = self._widgets['search_results'].focused_result
+            if prev_focused != now_focused:
+                self.job.result_focused(now_focused)
 
         # Alt-Enter
-        @self.bind_key('escape', 'enter')
+        @self.keybindings_local.add('escape', 'enter')
         def _(event):
             url = self._widgets['search_results'].focused_result.url
             browser.open(url)
@@ -176,7 +178,6 @@ class WebDbSearchJobWidget(JobWidgetBase):
             children=[
                 HSplit(
                     children=layout,
-                    # key_bindings=self._make_keybindings(),
                     style='class:dialog.search',
                 ),
             ],
@@ -227,14 +228,14 @@ class _SearchResults(DynamicContainer):
         if self._focused_index < len(self._results) - 1:
             self._focused_index += 1
 
-    def select_previous(self):
+    def focus_previous(self):
         if self._focused_index > 0:
             self._focused_index -= 1
 
-    def select_first(self):
+    def focus_first(self):
         self._focused_index = 0
 
-    def select_last(self):
+    def focus_last(self):
         self._focused_index = len(self._results) - 1
 
     def _get_text_fragments(self):
