@@ -72,9 +72,6 @@ class TUI:
             mouse_support=False,
             on_invalidate=self._update_jobs_container,
         )
-        # Make escape key work
-        app.timeoutlen = 0.1
-        app.ttimeoutlen = 0.1
         return app
 
     def add_jobs(self, *jobs):
@@ -107,12 +104,6 @@ class TUI:
     def _update_jobs_container(self, _=None):
         enabled_jobs = self._enabled_jobs
 
-        # Unfocus currently focused widget
-        for jobinfo in enabled_jobs:
-            if jobinfo.widget.is_focused:
-                jobinfo.widget.focus_lost()
-                break
-
         # List interactive jobs first
         jobs_container = []
         for jobinfo in enabled_jobs:
@@ -121,35 +112,46 @@ class TUI:
 
                 # Focus the first unfinished job
                 if not jobinfo.job.is_finished:
-                    try:
-                        self._layout.focus(jobinfo.container)
-                    except ValueError:
-                        pass
-                        # _log.debug('Unfocusable job: %r', jobinfo.job.name)
-                    else:
-                        jobinfo.widget.focus_gained()
+                    self._update_focus(jobinfo)
 
-                        # Don't display more than one unfinished interactive job
-                        # unless any job has errors, in which case we are
-                        # terminating the application and display all jobs.
-                        if not any(jobinfo.job.errors for jobinfo in self._jobs.values()):
-                            break
+                    # Don't display more than one unfinished interactive job
+                    # unless any job has errors, in which case we are
+                    # terminating the application and display all jobs.
+                    if not any(jobinfo.job.errors for jobinfo in self._jobs.values()):
+                        break
 
         # Add background jobs below interactive jobs so the interactive widgets
         # don't change position when non-interactive widgets change size.
         for jobinfo in enabled_jobs:
-            if not jobinfo.widget.is_interactive:
+            if not jobinfo.widget.is_interactive and jobinfo.job.is_started:
                 jobs_container.append(jobinfo.container)
 
         self._jobs_container.children[:] = jobs_container
 
+    def _update_focus(self, to_jobinfo):
+        try:
+            self._layout.focus(to_jobinfo.container)
+        except ValueError:
+            pass
+            # _log.debug('Unfocusable job: %r', to_jobinfo.job.name)
+
     def _connect_jobs(self, *jobs):
         for job in jobs:
+            # Every time a job finishes, other jobs can become enabled due to
+            # the dependencies on other jobs or other conditions. We also want
+            # to display the next interactive job when an interactive job is
+            # done.
             job.signal.register('finished', self._handle_job_finished)
 
+            # A job can also signal explicitly that we should start previously
+            # disabled jobs.
+            job.signal.register('refresh_job_list', self._refresh_jobs)
+
     def _handle_job_finished(self, finished_job):
+        assert finished_job.is_finished
+
         # Terminate application if any job finished with non-zero exit code
-        if finished_job.is_finished and finished_job.exit_code != 0:
+        if finished_job.exit_code != 0:
             if not self._app_terminated:
                 _log.debug('Terminating application because of failed job: %r', finished_job.name)
             self._exit()
@@ -157,19 +159,19 @@ class TUI:
         else:
             enabled_jobs = [jobinfo.job for jobinfo in self._enabled_jobs]
 
-            # Terminate application if all jobs finished
             if all(job.is_finished for job in enabled_jobs):
+                # Terminate application if all jobs finished
                 _log.debug('All jobs finished')
                 self._exit()
+            else:
+                # Start and/or display the next interactive jobs
+                self._refresh_jobs()
 
-            # Update jobs unless its pointless because _exit() was called
-            elif not self._app_terminated:
-                # Every time a job finishes, other jobs can become enabled due
-                # to the dependencies on other jobs or other conditions. We also
-                # want to display the next interactive job when an interactive
-                # job is done.
-                self._start_jobs(*enabled_jobs)
-                self._update_jobs_container()
+    def _refresh_jobs(self):
+        # Update jobs unless its pointless because _exit() was called
+        if not self._app_terminated:
+            self._start_jobs(*[jobinfo.job for jobinfo in self._enabled_jobs])
+            self._update_jobs_container()
 
     def _start_jobs(self, *jobs):
         for job in jobs:
