@@ -197,12 +197,14 @@ class RadioList:
         @kb.add('up')
         @kb.add('c-p')
         @kb.add('k')
+        @kb.add('s-tab')
         def _(event):
             self.focused_index = max(0, self.focused_index - 1)
 
         @kb.add('down')
         @kb.add('c-n')
         @kb.add('j')
+        @kb.add('tab')
         def _(event):
             self.focused_index = min(len(self.choices) - 1, self.focused_index + 1)
 
@@ -383,7 +385,6 @@ class ActivityIndicator:
 
         self.container = Window(
             content=FormattedTextControl(lambda: self.text),
-            height=1,
             dont_extend_height=True,
             dont_extend_width=not extend_width,
             style=style,
