@@ -14,14 +14,17 @@ import logging  # isort:skip
 _log = logging.getLogger(__name__)
 
 
-def _is_list(value):
+def _is_iterable_type(cls):
+    return issubclass(cls, collections.abc.Iterable) and not issubclass(cls, str)
+
+def _is_iterable(value):
     return isinstance(value, collections.abc.Iterable) and not isinstance(value, str)
 
-def _any2list(value):
-    return list(value) if _is_list(value) else str(value).split()
+def _any2iterable(value):
+    return tuple(value) if _is_iterable(value) else tuple(str(value).split())
 
 def _any2string(value):
-    return ' '.join(str(v) for v in value) if _is_list(value) else str(value)
+    return ' '.join(str(v) for v in value) if _is_iterable(value) else str(value)
 
 
 def config_value(value, *, description=''):
@@ -77,13 +80,34 @@ class ConfigFiles(collections.abc.MutableMapping):
             self.read(section, filepath, ignore_missing=ignore_missing)
 
     def _build_types(self):
-        def get_type(value):
-            if _is_list(value):
-                return _any2list
-            else:
-                def converter(v, cls=type(value)):
-                    return cls(_any2string(v))
-            return converter
+        def make_config_type(value):
+            parent_class = type(value)
+
+            def preconvert(v):
+                # Convert non-sequence to sequence if we expect a sequence
+                if _is_iterable_type(parent_class):
+                    if not _is_iterable(v):
+                        return _any2iterable(v)
+                # Convert sequence to string if we expect a string
+                else:
+                    if _is_iterable(v):
+                        return _any2string(v)
+                return v
+
+            def __new__(cls, v):
+                v = preconvert(v)
+                return parent_class.__new__(cls, v)
+
+            clsname = (
+                parent_class.__name__[0].upper()
+                + parent_class.__name__[1:]
+                + 'ConfigType'
+            )
+            bases = (parent_class,)
+            attrs = {
+                '__new__': __new__,
+            }
+            return type(clsname, bases, attrs)
 
         types = {}
         for section, subsections in self._defaults.items():
@@ -91,7 +115,8 @@ class ConfigFiles(collections.abc.MutableMapping):
             for subsection, options in subsections.items():
                 types[section][subsection] = {}
                 for option, value in options.items():
-                    types[section][subsection][option] = get_type(value)
+                    types[section][subsection][option] = make_config_type(value)
+
         return types
 
     @utils.cached_property
@@ -176,7 +201,7 @@ class ConfigFiles(collections.abc.MutableMapping):
             for section in cfg.values():
                 for key in section:
                     if '\n' in section[key]:
-                        section[key] = [item for item in section[key].split('\n') if item]
+                        section[key] = tuple(item for item in section[key].split('\n') if item)
 
             return cfg
 
