@@ -105,7 +105,7 @@ def _make_resize_cmd(image_file, dimensions, resized_file):
         '-y',
         '-loglevel', 'level+error',
         '-i', f'file:{image_file}',
-        '-vf', f'scale={dimensions}',
+        '-vf', f'scale={dimensions}:force_original_aspect_ratio=decrease',
         f'file:{resized_file}',
     )
 
@@ -143,19 +143,27 @@ def resize(image_file, width=0, height=0, target_directory=None, target_filename
         raise errors.ImageResizeError(f'Height must be greater than zero: {height}')
 
     dimensions_map = {'width': int(width), 'height': int(height)}
+    ext_args = {'minlen': 3, 'maxlen': 4}
 
     def get_target_filename():
         if target_filename:
-            return str(target_filename)
-        elif width or height:
-            extension = ','.join(f'{k}={v}' for k, v in dimensions_map.items() if v)
-            return utils.fs.basename(
-                utils.fs.strip_extension(image_file)
-                + '.' + extension + '.'
-                + utils.fs.file_extension(image_file)
-            )
+            filename = utils.fs.strip_extension(target_filename, **ext_args)
+            extension = utils.fs.file_extension(target_filename, **ext_args)
+            if not extension:
+                extension = utils.fs.file_extension(image_file, **ext_args)
         else:
-            return utils.fs.basename(image_file)
+            filename = utils.fs.basename(utils.fs.strip_extension(image_file, **ext_args))
+            dimensions = ','.join(f'{k}={v}' for k, v in dimensions_map.items() if v)
+            if dimensions:
+                filename += f'.{dimensions}'
+            extension = utils.fs.file_extension(image_file, **ext_args)
+
+        if extension:
+            filename += f'.{extension}'
+        else:
+            filename += '.jpg'
+
+        return filename
 
     def get_target_directory():
         if target_directory:
