@@ -158,19 +158,13 @@ class MultiPredbApi:
         ):
             return SceneCheckResult.false
 
-        # Do we have enough information to pinpoint a single release?
-        needed_keys = utils.predbs.common.get_needed_keys(release_info)
-        if needed_keys and all(release_info[k] for k in needed_keys):
-            # We know which keys we need and all needed keys have values in
-            # `release_info`. If there are search results, we have a scene
-            # release.
-            results = await self.search(release)
-            if results:
-                return SceneCheckResult.true
-            else:
-                return SceneCheckResult.false
+        # We know at least `title` and `group`. If there are any search results,
+        # it should be a scene release.
+        results = await self.search(release)
+        if results:
+            return SceneCheckResult.true
         else:
-            return SceneCheckResult.unknown
+            return SceneCheckResult.false
 
     async def verify_release_name(self, content_path, release_name):
         """
@@ -402,8 +396,8 @@ class MultiPredbApi:
 
         # Stop other checks if this is not a scene release
         is_scene = await self.is_scene_release(release_name)
-        if not is_scene:
-            return SceneCheckResult.false, ()
+        if is_scene in (SceneCheckResult.false, SceneCheckResult.unknown):
+            return is_scene, ()
 
         # Combined exceptions from verify_release_name() and verify_release_files()
         exceptions = []
