@@ -72,8 +72,11 @@ class SceneQuery:
         # for multiple seasons ("S01S02") and multiple episodes
         # ("S01E01S02E02E03"). It also means we don't have to wait 40 seconds
         # per episode when querying srrdb for a season pack.
-        needed_keys = [k for k in utils.predbs.common.get_needed_keys(release)
-                       if k not in ('group', 'episodes')]
+        needed_keys = utils.predbs.common.get_needed_keys(
+            release,
+            exclude=('group', 'episodes'),
+        )
+
         keywords = [release[key] for key in needed_keys
                     if key in release]
 
