@@ -814,7 +814,13 @@ class ReleaseName(collections.abc.Mapping):
                     self.country_required = True
 
     def format(self, separator=None):
-        """Assemble all parts into string"""
+        """
+        Assemble all parts into string
+
+        :param separator: Separator to use instead of space
+
+            The typical use case would be ``.``.
+        """
         parts = [self.title_with_aka_and_year]
 
         if self.type in (ReleaseType.season, ReleaseType.episode) and not self.date:
@@ -843,7 +849,12 @@ class ReleaseName(collections.abc.Mapping):
             # Remove non-word characters like (e.g.: ,:) with some exceptions
             joined = re.sub(r'[^ \w\.-]', '', joined)
 
-        return joined.replace(' ', sep)
+        formatted = joined.replace(' ', sep)
+
+        # Deduplicate "."
+        formatted = re.sub(r'\.+', '.', formatted)
+
+        return formatted
 
 
 class ReleaseInfo(collections.abc.MutableMapping):
@@ -1394,22 +1405,31 @@ class Episodes(dict):
             >>> Episodes.from_string('E01S03E06.bar.E02')
             {'': ('1', '2',), '3': ('6',)}
         """
-        def only_digits(string):
-            return ''.join(c for c in string if c in '0123456789')
+        def extract_number(string):
+            return ''.join(c for c in string if c in '0123456789').lstrip('0')
 
         def split_episodes(string):
-            return {only_digits(e) for e in string.split('E') if e.strip()}
+            return {extract_number(e) for e in string.split('E') if e.strip()}
+
+        # Extract episode information to get "S..E.." string without any other
+        # characters. The original value might have delimiters,
+        # e.g. "...S09E14-E15...", and we want "S09E14E15".
+        episodes_string = ''.join(re.findall(
+            (
+                r'(?i:[^SE\d]*|^)'
+                r'((?i:[SE]\d+)+)'
+                r'(?i:[^SE\d]+|$)'
+            ),
+            str(value).upper(),
+        ))
 
         seasons = collections.defaultdict(lambda: set())
-        for word in re.split(r'[\. ]+', str(value)):
-            word = word.upper()
-            if cls.has_episodes_info(word):
-                for part in (k for k in word.split('S') if k):
-                    season = re.sub(r'E.*$', '', part)
-                    season = str(int(season)) if season else ''
-                    episodes = re.sub(r'^\d+', '', part)
-                    episodes = split_episodes(episodes) if episodes else ()
-                    seasons[season].update(episodes)
+        for part in (k for k in episodes_string.split('S') if k):
+            season = re.sub(r'E.*$', '', part)
+            season = str(int(season)) if season else ''
+            episodes = re.sub(r'^\d+', '', part)
+            episodes = split_episodes(episodes) if episodes else ()
+            seasons[season].update(episodes)
 
         args = {season: tuple(natsort.natsorted(episodes))
                 for season, episodes in natsort.natsorted(seasons.items())}
