@@ -5,7 +5,9 @@ Create torrent file
 import collections
 import datetime
 import errno
+import fnmatch
 import os
+import re
 import time
 
 from .. import __project_name__, __version__, constants, errors, utils
@@ -37,34 +39,16 @@ def create(*, content_path, announce, source, torrent_path,
     :param int piece_size_min: Minimum piece size
     :param int piece_size_max: Maximum piece size
     :param init_callback: Callable that is called once before torrent generation
-        commences. It gets `content_path` as a tree where each node is a tuple
-        in which the first item is the directory name and the second item is a
-        sequence of `(file_name, file_size)` tuples.
-
-        Example:
-
-        .. code::
-
-           ('Parent',
-               ('Foo', (
-                   ('Picture.jpg', 82489),
-                   ('Music.mp3', 5315672),
-                   ('More files', (
-                       ('This.txt', 57734),
-                       ('And that.txt', 184),
-                       ('Also some of this.txt', 88433),
-                   )),
-               )),
-               ('Bar', (
-                   ('Yee.mp4', 288489392),
-                   ('Yah.mkv', 3883247384),
-               )),
-           )
+        commences with a :class:`Files` object
     :param progress_callback: Callable that is called at regular intervals with
         a :class:`CreateTorrentProgress` or :class:`FindTorrentProgress` object
         as a positional argument
-    :param exclude: Sequence of regular expressions that are matched against
-        file system paths. Matching files are not included in the torrent.
+    :param exclude: Sequence of glob patterns (:class:`str`) and
+        :class:`re.Pattern` objects (return value from :func:`re.compile`)
+
+        Files beneath `content_path` are excluded from the torrent.
+
+        Glob patterns are matched case-insensitively.
     :param bool use_cache: Whether to get piece hashes from previously created
         torrents or from `reuse_torrent_path`
     :param reuse_torrent_path: Path to existing torrent file to get hashed
@@ -96,14 +80,14 @@ def create(*, content_path, announce, source, torrent_path,
     # Create Torrent object
     torrent = _get_torrent(
         content_path=content_path,
-        exclude=exclude,
+        exclude=_get_exclude_regexs(exclude),
         announce=announce,
         source=source,
         piece_size_min=piece_size_min,
         piece_size_max=piece_size_max,
     )
     # Report files with `exclude` applied
-    cancelled = init_callback(_make_file_tree(torrent.filetree))
+    cancelled = init_callback(Files(torrent))
     if cancelled:
         return None
 
@@ -135,6 +119,18 @@ def create(*, content_path, announce, source, torrent_path,
     return torrent_path
 
 
+def _get_exclude_regexs(exclude):
+    regexs = []
+    for pattern in exclude:
+        if utils.is_regex_pattern(pattern):
+            regexs.append(pattern)
+        elif isinstance(pattern, str):
+            regexs.append(re.compile(fnmatch.translate(str(pattern)), flags=re.IGNORECASE))
+        else:
+            raise TypeError(f'Unexpected exclude type: {pattern!r}')
+    return regexs
+
+
 def _get_torrent(*, content_path, exclude, announce, source, piece_size_min, piece_size_max):
     try:
         return torf.Torrent(
@@ -248,15 +244,65 @@ def _copy_torrent_info(from_torrent, to_torrent):
         to_info['files'] = from_info['files']
 
 
-def _make_file_tree(filetree):
-    files = []
-    for name,file in filetree.items():
-        if isinstance(file, collections.abc.Mapping):
-            subtree = _make_file_tree(file)
-            files.append((name, subtree))
-        else:
-            files.append((name, file.size))
-    return tuple(files)
+class Files:
+    """Structured torrent file content"""
+
+    def __init__(self, torrent):
+        self._list = self._make_file_list(torrent.filepaths)
+        self._tree = self._make_file_tree(torrent.filetree, parent_path=str(torrent.path.parent))
+
+    def _make_file_list(self, filepaths):
+        return tuple(str(filepath) for filepath in filepaths)
+
+    def _make_file_tree(self, filetree, parent_path=''):
+        files = []
+
+        for name, file in filetree.items():
+            path = os.sep.join((parent_path, name)).strip(os.sep)
+
+            if isinstance(file, collections.abc.Mapping):
+                subtree = self._make_file_tree(file)
+                files.append((path, subtree))
+            else:
+                files.append((path, file.size))
+
+        return tuple(files)
+
+    @property
+    def list(self):
+        """Sequence of existing file paths (:class:`str`)"""
+        return self._list
+
+    @property
+    def tree(self):
+        """
+        Nested files
+
+        This is a tree where each node is a tuple in which the first item is the
+        directory name and the second item is a sequence of `(file_name,
+        file_size)` or `(file_name, sub_tree)` tuples.
+
+        Example:
+
+        .. code::
+
+           ('Parent',
+               ('Foo', (
+                   ('Picture.jpg', 82489),
+                   ('Music.mp3', 5315672),
+                   ('More files', (
+                       ('This.txt', 57734),
+                       ('And that.txt', 184),
+                       ('Also some of this.txt', 88433),
+                   )),
+               )),
+               ('Bar', (
+                   ('Yee.mp4', 288489392),
+                   ('Yah.mkv', 3883247384),
+               )),
+           )
+        """
+        return self._tree
 
 
 class _CallbackBase:
@@ -459,3 +505,30 @@ class FindTorrentProgress(collections.namedtuple(
         - ``time_finished`` (:class:`~.datetime.datetime.datetime`)
         - ``time_started`` (:class:`~.datetime.datetime.datetime`)
     """
+
+
+def filter_files(content_path, exclude=()):
+    """
+    Get a list of files beneath `content_path` with files excluded
+
+    This uses the same exclusion method as :func:`create`. This is useful if you
+    need a list of files in a torrent without actually creating the torrent.
+
+    :param content_path: See :func:`create`
+    :param exclude: See :func:`create`
+
+    :raise ContentError: if anything goes wrong
+    """
+    try:
+        torrent = _get_torrent(
+            content_path=content_path,
+            exclude=_get_exclude_regexs(exclude),
+            announce='http://dummy.local',
+            source=None,
+            piece_size_min=None,
+            piece_size_max=None,
+        )
+    except errors.TorrentError as e:
+        raise errors.ContentError(e)
+    else:
+        return [str(f) for f in torrent.filepaths]
