@@ -676,7 +676,7 @@ def find_videos(path):
     name), episodes are returned and all other files are excluded.
 
     Except for season packs, video files are filtered through
-    :func:`filter_similar_duration` to exclude samples and such.
+    :func:`filter_main_videos` to exclude samples and such.
 
     :param str path: Path to file or directory
 
@@ -713,7 +713,7 @@ def find_videos(path):
         files = fs.file_list(path, extensions=constants.VIDEO_FILE_EXTENSIONS)
 
         # Find episodes in season pack by file name to avoid time consuming
-        # call to filter_similar_duration()
+        # call to filter_main_videos()
         episode_regex = re.compile(
             rf'(?:^|{release.DELIM})'
             rf'(?i:S|Season{release.DELIM}?)\d+{release.DELIM}?(?i:E|Episode{release.DELIM}?)\d+'
@@ -732,12 +732,12 @@ def find_videos(path):
     else:
         # To avoid using samples, extras, very short .VOBs (e.g. menus), remove
         # any videos that are very short compared to the average duration.
-        considered_files = filter_similar_duration(files)
+        considered_files = filter_main_videos(files)
         return normalize_files(considered_files)
 
 
 @functools.lru_cache(maxsize=None)
-def filter_similar_duration(video_file_paths):
+def filter_main_videos(video_file_paths):
     """
     Filter `video_file_paths` for comparable video duration
 
@@ -804,7 +804,7 @@ def make_ffmpeg_input(path):
         # by finding the first .VOB with a reasonable length.
         vobs = fs.file_list(os.path.join(path, 'VIDEO_TS'))
         _log.debug('All VOBs: %r', vobs)
-        reasonable_vobs = filter_similar_duration(vobs)
+        reasonable_vobs = filter_main_videos(vobs)
         _log.debug('Reasonable VOBs: %r', reasonable_vobs)
         if reasonable_vobs:
             return reasonable_vobs[0]
