@@ -324,72 +324,49 @@ class ImdbApi(WebDbApiBase):
         return ''
 
     async def _title_original(self, id):
-        akas = await self._get_akas(id)
-        return akas.get('original', '')
+        # /title/tt.../releaseinfo/#akas: Find "(original title)" row in table
+        # Example: https://www.imdb.com/title/tt1405737/releaseinfo/#akas
+        soup = await self._get_soup(f'title/{id}/releaseinfo')
+        for tag in soup.find_all('button', attrs={'class': 'ipc-metadata-list-item__label'}):
+            text = utils.html.as_text(tag)
+            if 'original' in text:
+                return utils.html.as_text(tag.next_sibling)
+
+        return ''
 
     async def _titles_english(self, id):
-        akas = await self._get_akas(id)
-        return [akas.get('english', '')]
+        soup = await self._get_soup(f'title/{id}/releaseinfo')
 
-    @utils.asyncmemoize
-    async def _get_akas(self, id):
-        soup = await self._get_soup(f'title/{id}')
-        main_title = sub_title = None
-
-        # The big title on the main page. This is usually the English title,
-        # even for non-English movies.
-        tag = soup.find(attrs={'data-testid': 'hero-title-block__title'})
+        # Get the main (usually English) title from the <head>
+        tag = soup.select_one('head meta[property="og:title"]')
         if tag:
-            main_title = utils.html.as_text(tag)
+            match = re.search(r'^(.*)\s+\(.*?\)\s*', tag['content'])
+            if match:
+                return [match.group(1).strip()]
 
-        # The small title below the main title. This is the original title for
-        # non-English movies and not displayed for English movies.
-        tag = soup.find(attrs={'data-testid': 'hero-title-block__original-title'})
-        if tag:
-            text = utils.html.as_text(tag)
-            sub_title = re.sub(r'^Original\s+title:\s+', '', text, flags=re.IGNORECASE)
-
-        if sub_title:
-            # Probably non-English title
-            return {'original': sub_title, 'english': main_title}
-        else:
-            # Probably English title
-            return {'original': main_title, 'english': main_title}
+        return ['']
 
     async def type(self, id):
         if id:
-            soup = await self._get_soup(f'title/{id}/')
+            soup = await self._get_soup(f'title/{id}/reference')
 
-            # Old website design
-            subtext_tag = soup.find(class_='subtext')
-            if subtext_tag:
-                # reversed() because interesting info is on the right side
-                subtext = ' '.join(reversed(tuple(subtext_tag.stripped_strings))).lower()
+            tag = soup.find(class_='ipl-inline-list')
+            text = ' '.join(reversed(tuple(tag.stripped_strings))).lower()
 
-            else:
-                # New website design
-                subtext_tag = soup.find(attrs={'data-testid': 'hero-title-block__metadata'})
-                if subtext_tag:
-                    subtext = ' '.join(subtext_tag.stripped_strings).lower()
-
-            if subtext:
-                if 'episode' in subtext:
-                    return ReleaseType.episode
-                elif 'tv series' in subtext:
-                    return ReleaseType.season
-                elif re.search(r'tv mini[- ]series', subtext):
-                    return ReleaseType.season
-                elif subtext.endswith('video') or subtext.startswith('video'):
-                    return ReleaseType.movie
-                elif 'tv movie' in subtext:
-                    return ReleaseType.movie
-                elif (
-                    # Look for year (old website design)
-                    re.search(r'^\d+ [a-z]+ \d{4}', subtext)
-                    # Look for year (new website design)
-                    or re.search(r'^\d{4}', subtext)
-                ):
-                    return ReleaseType.movie
+            if 'episode' in text:
+                return ReleaseType.episode
+            elif 'tv series' in text:
+                return ReleaseType.season
+            elif re.search(r'tv mini[- ]series', text):
+                return ReleaseType.season
+            elif 'tv movie' in text:
+                return ReleaseType.movie
+            elif 'movie' in text:
+                return ReleaseType.movie
+            elif 'short' in text:
+                return ReleaseType.movie
+            elif 'video' in text:
+                return ReleaseType.movie
 
         return ReleaseType.unknown
 
@@ -400,28 +377,13 @@ class ImdbApi(WebDbApiBase):
 
     async def year(self, id):
         if id:
-            soup = await self._get_soup(f'title/{id}/')
+            soup = await self._get_soup(f'title/{id}/reference')
 
-            # Movies (old website design)
-            year_tag = soup.find(id='titleYear')
-            if year_tag:
-                return ''.join(year_tag.stripped_strings).strip('()')
-
-            # Series (old website design)
-            subtext_tag = soup.find(class_='subtext')
-            if subtext_tag:
-                # reversed() because interesting info is on the right side
-                subtext = ' '.join(reversed(tuple(subtext_tag.stripped_strings)))
-            else:
-                # Series (new website design)
-                subtext_tag = soup.find(attrs={'data-testid': 'hero-title-block__metadata'})
-                if subtext_tag:
-                    subtext = ' '.join(subtext_tag.stripped_strings)
-
-            if subtext:
-                match = re.search(r'\b(\d{4})\b', subtext)
-                if match:
-                    return match.group(1)
+            tag = soup.find(class_='titlereference-title-year')
+            text = ' '.join(reversed(tuple(tag.stripped_strings))).lower()
+            match = re.search(r'\b(\d{4})\b', text)
+            if match:
+                return match.group(1)
 
         return ''
 
