@@ -44,6 +44,8 @@ class TmdbApi(WebDbApiBase):
         if query.id:
             async def generate_result(id):
                 _log.debug('Getting ID: %r', id)
+                title_english = await self.title_english(id)
+                title_original = await self.title_original(id)
                 return _TmdbSearchResult(
                     tmdb_api=self,
                     cast=functools.partial(self.cast, id),
@@ -51,7 +53,7 @@ class TmdbApi(WebDbApiBase):
                     genres=functools.partial(self.genres, id),
                     id=id,
                     summary=functools.partial(self.summary, id),
-                    title=await self.title_english(id),
+                    title=title_english or title_original,
                     title_english=functools.partial(self.title_english, id),
                     title_original=functools.partial(self.title_original, id),
                     type=await self.type(id),
@@ -214,30 +216,24 @@ class TmdbApi(WebDbApiBase):
             return overview
         return ''
 
-    async def title_english(self, id):
-        if id:
-            soup = await self._get_soup(id)
-            title_tag = soup.find(class_='title')
-            if title_tag:
-                title_parts = list(title_tag.stripped_strings)
-                if title_parts:
-                    return title_parts[0]
-        return ''
-
-    async def title_original(self, id):
-        if id:
-            soup = await self._get_soup(id)
+    async def _title_original(self, id):
+        soup = await self._get_soup(id)
+        try:
+            # Find non-English title
             title_tag = soup.find(string=re.compile(r'Original (?:Title|Name)'))
-            if title_tag:
-                try:
-                    parent_tag = title_tag.parent.parent
-                except AttributeError:
-                    pass
-                else:
-                    strings = tuple(parent_tag.stripped_strings)
-                    if len(strings) >= 2:
-                        return strings[1]
-        return await self.title_english(id)
+            parent_tag = title_tag.parent.parent
+            strings = tuple(parent_tag.stripped_strings)
+            return strings[1]
+        except (AttributeError, TypeError, ValueError, IndexError):
+            # Default to English title
+            english_titles = await self._titles_english(id)
+            return english_titles[0]
+
+    async def _titles_english(self, id):
+        soup = await self._get_soup(id)
+        title_tag = soup.find(class_='title')
+        title_parts = list(title_tag.stripped_strings)
+        return (title_parts[0],)
 
     async def type(self, id):
         if id:
